aboutsummaryrefslogtreecommitdiffstats
path: root/src/java/org
diff options
context:
space:
mode:
authorYegor Kozlov <yegor@apache.org>2007-11-03 19:50:40 +0000
committerYegor Kozlov <yegor@apache.org>2007-11-03 19:50:40 +0000
commit80c35b59fde4e1613e22cf19a9c236640f8a8700 (patch)
treec7feb5cba6d7e2b0b347290dade80c15a568ca65 /src/java/org
parent1b4416d11645031af412b5f49a298d0dbcbe9b52 (diff)
downloadpoi-80c35b59fde4e1613e22cf19a9c236640f8a8700.tar.gz
poi-80c35b59fde4e1613e22cf19a9c236640f8a8700.zip
fixed a silly typo in the method signature. It should be HFFSPicture.getPreferredSize(), not HFFSPicture.getPrefferedSize()
git-svn-id: https://svn.apache.org/repos/asf/poi/trunk@591667 13f79535-47bb-0310-9956-ffa450edef68
Diffstat (limited to 'src/java/org')
-rw-r--r--src/java/org/apache/poi/hssf/usermodel/HSSFPicture.java10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/java/org/apache/poi/hssf/usermodel/HSSFPicture.java b/src/java/org/apache/poi/hssf/usermodel/HSSFPicture.java
index 79649b06a8..9aa0e966d1 100644
--- a/src/java/org/apache/poi/hssf/usermodel/HSSFPicture.java
+++ b/src/java/org/apache/poi/hssf/usermodel/HSSFPicture.java
@@ -79,7 +79,7 @@ public class HSSFPicture
HSSFClientAnchor anchor = (HSSFClientAnchor)getAnchor();
anchor.setAnchorType(2);
- HSSFClientAnchor pref = getPrefferedSize();
+ HSSFClientAnchor pref = getPreferredSize();
int row2 = anchor.getRow1() + (pref.getRow2() - pref.getRow1());
int col2 = anchor.getCol1() + (pref.getCol2() - pref.getCol1());
@@ -94,19 +94,19 @@ public class HSSFPicture
}
/**
* Calculate the preffered size for this picture.
*
* @return HSSFClientAnchor with the preffered size for this image
* @since POI 3.0.2
*/
- public HSSFClientAnchor getPrefferedSize(){
+ public HSSFClientAnchor getPreferredSize(){
HSSFClientAnchor anchor = new HSSFClientAnchor();
EscherBSERecord bse = (EscherBSERecord)patriarch.sheet.book.getBSERecord(pictureIndex);
byte[] data = bse.getBlipRecord().getPicturedata();
int type = bse.getBlipTypeWin32();
switch (type){
//we can calculate the preffered size only for JPEG and PNG
//other formats like WMF, EMF and PICT are not supported in Java
case HSSFWorkbook.PICTURE_TYPE_JPEG:
case HSSFWorkbook.PICTURE_TYPE_PNG:
@@ -94,19 +94,19 @@ public class HSSFPicture
}
/**
- * Calculate the preffered size for this picture.
+ * Calculate the preferred size for this picture.
*
@@ -94,19 +94,19 @@ public class HSSFPicture
*
- * @return HSSFClientAnchor with the preffered size for this image
+ * @return HSSFClientAnchor with the preferred size for this image
* @since POI 3.0.2
*/
@@ -94,19 +94,19 @@ public class HSSFPicture
int type = bse.getBlipTypeWin32();
switch (type){
- //we can calculate the preffered size only for JPEG and PNG
+ //we can calculate the preferred size only for JPEG and PNG
//other formats like WMF, EMF and PICT are not supported in Java
case HSSFWorkbook.PICTURE_TYPE_JPEG: